@@ -6,7 +6,7 @@
 
 package Lemonldap::NG::Manager::Build::Attributes;
 
-our $VERSION = '1.9.7';
+our $VERSION = '1.9.10';
 use strict;
 use Regexp::Common qw/URI/;
 
@@ -25,6 +25,7 @@ my $perlExpr = sub {
     foreach my $f (@cf) {
         $s = "sub $f {1} $s";
     }
+    no warnings( 'redefine', 'uninitialized' );
     eval "$s $val";
     return $@ ? ( 1, "__badExpression__: $@" ) : (1);
 };
@@ -347,7 +348,6 @@ sub attributes {
 
         # Menu
         activeTimer => {
-            default       => 0,
             type          => 'bool',
             default       => 1,
             documentation => 'Enable timers on portal pages',
@@ -361,6 +361,16 @@ sub attributes {
             },
             documentation => 'Applications list',
         },
+        portalErrorOnExpiredSession => {
+            type          => 'bool',
+            default       => 1,
+            documentation => 'Show error if session is expired',
+        },
+        portalErrorOnMailNotFound => {
+            type          => 'bool',
+            default       => 0,
+            documentation => 'Show error if mail is not found in password reset process',
+        },
         portalOpenLinkInNewWindow => {
             type          => 'bool',
             default       => 0,
@@ -989,6 +999,7 @@ sub attributes {
                     foreach my $f (@cf) {
                         $s = "sub $f {1} $s";
                     }
+                    no warnings( 'redefine', 'uninitialized' );
                     eval $s;
                     return $@ ? ( 1, "__badExpression__: $@" ) : (1);
                 },
@@ -1022,6 +1033,7 @@ sub attributes {
                     foreach my $f (@cf) {
                         $s = "sub $f {1} $s";
                     }
+                    no warnings( 'redefine', 'uninitialized' );
                     eval $s;
                     return $@ ? ( 1, "__badExpression__: $@" ) : (1);
                   }
@@ -2433,6 +2445,7 @@ m{^(?:ldapi://[^/]*/?|\w[\w\-\.]*(?::\d{1,5})?|ldap(?:s|\+tls)?://\w[\w\-\.]*(?:
         oidcRPMetaDataOptionsExtraClaims =>
           { type => 'keyTextContainer', default => {} },
         oidcRPMetaDataOptionsBypassConsent => { type => 'bool', default => 0 },
+        oidcRPMetaDataOptionsPostLogoutRedirectUris => { type => 'text', },
 
     };
 }
