@@ -344,6 +344,11 @@ function templates(tpl,key) {
             "id" : tpl+"s/"+key+"/"+"oidcRPMetaDataOptionsRedirectUris",
             "title" : "oidcRPMetaDataOptionsRedirectUris"
          },
+         {
+            "get" : tpl+"s/"+key+"/"+"oidcRPMetaDataOptionsPostLogoutRedirectUris",
+            "id" : tpl+"s/"+key+"/"+"oidcRPMetaDataOptionsPostLogoutRedirectUris",
+            "title" : "oidcRPMetaDataOptionsPostLogoutRedirectUris"
+         },
          {
             "default" : 0,
             "get" : tpl+"s/"+key+"/"+"oidcRPMetaDataOptionsBypassConsent",
