@@ -11,7 +11,7 @@ use Lemonldap::NG::Portal::Simple;
 use Lemonldap::NG::Portal::_SAML;    #inherits
 use Lemonldap::NG::Common::Conf::SAML::Metadata;
 
-our $VERSION = '1.9.6';
+our $VERSION = '1.9.8';
 our @ISA     = qw(Lemonldap::NG::Portal::_SAML);
 
 ## @apmethod int authInit()
@@ -299,52 +299,57 @@ sub extractFormInfo {
             $self->{_samlToken} = $saml_token;
 
             # Restore initial SAML request in case of proxying
-            my $moduleOptions = $self->{samlStorageOptions} || {};
-            $moduleOptions->{backend} = $self->{samlStorage};
-            my $module = "Lemonldap::NG::Common::Apache::Session";
+            if ($assertion_responded) {
+                my $moduleOptions = $self->{samlStorageOptions} || {};
+                $moduleOptions->{backend} = $self->{samlStorage};
+                my $module = "Lemonldap::NG::Common::Apache::Session";
 
-            my $saml_sessions =
-              $module->searchOn( $moduleOptions, "ProxyID",
-                $assertion_responded );
+                my $saml_sessions =
+                  $module->searchOn( $moduleOptions, "ProxyID",
+                    $assertion_responded );
 
-            if ( my @saml_sessions_keys = keys %$saml_sessions ) {
+                if ( my @saml_sessions_keys = keys %$saml_sessions ) {
 
-                # Warning if more than one session found
-                if ( $#saml_sessions_keys > 0 ) {
-                    $self->lmLog(
+                    # Warning if more than one session found
+                    if ( $#saml_sessions_keys > 0 ) {
+                        $self->lmLog(
 "More than one SAML proxy session found for ID $assertion_responded",
-                        'warn'
-                    );
-                }
+                            'warn'
+                        );
+                    }
 
-                # Take the first session
-                my $saml_session = shift @saml_sessions_keys;
+                    # Take the first session
+                    my $saml_session = shift @saml_sessions_keys;
 
-                # Get session
-                $self->lmLog(
+                    # Get session
+                    $self->lmLog(
 "Retrieve SAML proxy session $saml_session for ID $assertion_responded",
-                    'debug'
-                );
+                        'debug'
+                    );
 
-                my $samlSessionInfo = $self->getSamlSession($saml_session);
+                    my $samlSessionInfo = $self->getSamlSession($saml_session);
 
-                $self->{_proxiedRequest} = $samlSessionInfo->data->{Request};
-                $self->{_proxiedMethod}  = $samlSessionInfo->data->{Method};
-                $self->{_proxiedRelayState} =
-                  $samlSessionInfo->data->{RelayState};
-                $self->{_proxiedArtifact} = $samlSessionInfo->data->{Artifact};
+                    $self->{_proxiedRequest} =
+                      $samlSessionInfo->data->{Request};
+                    $self->{_proxiedMethod} = $samlSessionInfo->data->{Method};
+                    $self->{_proxiedRelayState} =
+                      $samlSessionInfo->data->{RelayState};
+                    $self->{_proxiedArtifact} =
+                      $samlSessionInfo->data->{Artifact};
 
                # Save values in hidden fields in case of other user interactions
-                $self->setHiddenFormValue( 'SAMLRequest',
-                    $self->{_proxiedRequest} );
-                $self->setHiddenFormValue( 'Method', $self->{_proxiedMethod} );
-                $self->setHiddenFormValue( 'RelayState',
-                    $self->{_proxiedRelayState} );
-                $self->setHiddenFormValue( 'SAMLart',
-                    $self->{_proxiedArtifact} );
+                    $self->setHiddenFormValue( 'SAMLRequest',
+                        $self->{_proxiedRequest} );
+                    $self->setHiddenFormValue( 'Method',
+                        $self->{_proxiedMethod} );
+                    $self->setHiddenFormValue( 'RelayState',
+                        $self->{_proxiedRelayState} );
+                    $self->setHiddenFormValue( 'SAMLart',
+                        $self->{_proxiedArtifact} );
 
-                # Delete session
-                $samlSessionInfo->remove();
+                    # Delete session
+                    $samlSessionInfo->remove();
+                }
             }
 
             return PE_OK;
