@@ -9,8 +9,9 @@ use strict;
 use Lemonldap::NG::Portal::Simple;
 use Lemonldap::NG::Portal::_CAS;
 use base qw(Lemonldap::NG::Portal::_CAS Lemonldap::NG::Portal::_LibAccess);
+use URI;
 
-our $VERSION = '1.4.3';
+our $VERSION = '1.9.8';
 
 ## @method void issuerDBInit()
 # Nothing to do
@@ -58,6 +59,11 @@ sub issuerForUnAuthUser {
         $self->setHiddenFormValue( 'renew',   $renew );
         $self->setHiddenFormValue( 'gateway', $gateway );
 
+        # Set values in %ENV
+        $ENV{"llng_cas_service"} = $service;
+        $ENV{"llng_cas_renew"}   = $renew;
+        $ENV{"llng_cas_gateway"} = $gateway;
+
         # Gateway
         if ( $gateway eq 'true' ) {
 
@@ -136,19 +142,37 @@ sub issuerForUnAuthUser {
 
         $self->lmLog( "Service ticket session $ticket found", 'debug' );
 
-        # Check service
-        unless ( $service eq $casServiceSession->data->{service} ) {
-            $self->lmLog(
-                "Submitted service $service does not match initial service "
-                  . $casServiceSession->data->{service},
-                'error'
-            );
-            $self->deleteCasSession($casServiceSession);
-            $self->returnCasValidateError();
-        }
+        my $service1_uri = URI->new($service);
+        my $service2_uri = URI->new( $casServiceSession->data->{service} );
 
-        $self->lmLog( "Submitted service $service math initial servce",
-            'debug' );
+        # Check service
+        unless ( $service1_uri->eq($service2_uri) ) {
+
+            # Tolerate that relative URI are the same
+            if (   $service1_uri->rel($service2_uri) eq "./"
+                or $service2_uri->rel($service1_uri) eq "./" )
+            {
+                $self->lmLog(
+"Submitted service $service1_uri does not exactly match initial service "
+                      . $service2_uri
+                      . ' but difference is tolerated.',
+                    'warn'
+                );
+            }
+            else {
+                $self->lmLog(
+                    "Submitted service $service does not match initial service "
+                      . $casServiceSession->data->{service},
+                    'error'
+                );
+                $self->deleteCasSession($casServiceSession);
+                $self->returnCasValidateError();
+            }
+        }
+        else {
+            $self->lmLog( "Submitted service $service math initial servce",
+                'debug' );
+        }
 
         # Check renew
         if ( $renew eq 'true' ) {
@@ -259,21 +283,39 @@ sub issuerForUnAuthUser {
 
         $self->lmLog( "$urlType ticket session $ticket found", 'debug' );
 
+        my $service1_uri = URI->new($service);
+        my $service2_uri = URI->new( $casServiceSession->data->{service} );
+
         # Check service
-        unless ( $service eq $casServiceSession->data->{service} ) {
-            $self->lmLog(
-                "Submitted service $service does not match initial service "
-                  . $casServiceSession->data->{service},
-                'error'
-            );
+        unless ( $service1_uri->eq($service2_uri) ) {
 
-            $self->deleteCasSession($casServiceSession);
-            $self->returnCasServiceValidateError( 'INVALID_SERVICE',
-                'Submitted service does not match initial service' );
+            # Tolerate that relative URI are the same
+            if (   $service1_uri->rel($service2_uri) eq "./"
+                or $service2_uri->rel($service1_uri) eq "./" )
+            {
+                $self->lmLog(
+"Submitted service $service1_uri does not exactly match initial service "
+                      . $service2_uri
+                      . ' but difference is tolerated.',
+                    'warn'
+                );
+            }
+            else {
+                $self->lmLog(
+                    "Submitted service $service does not match initial service "
+                      . $casServiceSession->data->{service},
+                    'error'
+                );
+
+                $self->deleteCasSession($casServiceSession);
+                $self->returnCasServiceValidateError( 'INVALID_SERVICE',
+                    'Submitted service does not match initial service' );
+            }
+        }
+        else {
+            $self->lmLog( "Submitted service $service match initial service",
+                'debug' );
         }
-
-        $self->lmLog( "Submitted service $service match initial servce",
-            'debug' );
 
         # Check renew
         if ( $renew eq 'true' ) {
@@ -396,10 +438,22 @@ sub issuerForUnAuthUser {
 
         $self->lmLog( "Get username $username", 'debug' );
 
+        # Get attributes [CAS 3.0]
+        my $attributes = {};
+        if ( defined $self->{casAttributes} ) {
+            foreach my $casAttribute ( keys %{ $self->{casAttributes} } ) {
+                my $localSessionValue =
+                  $localSession->data->{ $self->{casAttributes}->{$casAttribute}
+                  };
+                $attributes->{$casAttribute} = $localSessionValue
+                  if defined $localSessionValue;
+            }
+        }
+
         # Return success message
         $self->deleteCasSession($casServiceSession);
         $self->returnCasServiceValidateSuccess( $username,
-            $casProxyGrantingTicketIOU, $proxies );
+            $casProxyGrantingTicketIOU, $proxies, $attributes );
 
         # We should not be there
         return PE_ERROR;
@@ -792,7 +846,7 @@ L<http://forge.objectweb.org/project/showfiles.php?group_id=274>
 
 =item Copyright (C) 2012 by François-Xavier Deltombe, E<lt>fxdeltombe@gmail.com.E<gt>
 
-=item Copyright (C) 2010, 2011, 2012 by Clement Oudot, E<lt>clem.oudot@gmail.comE<gt>
+=item Copyright (C) 2010-2012 by Clement Oudot, E<lt>clem.oudot@gmail.comE<gt>
 
 =back
 
